@@ -11,7 +11,7 @@ if TYPE_CHECKING:
 class EventsBase:
     events_registered: Dict[
         Union[GroupEventType, UserEventType],
-        Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"],
+        Type[Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"]],
     ] = {}
 
     def __init__(
@@ -33,7 +33,7 @@ class EventsBase:
 
     def get(
         self, event_type: Union[int, str, GroupEventType, UserEventType]
-    ) -> Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"]:
+    ) -> Callable[..., Union["GroupTypes.UnifiedTypes", "UserTypes.UnifiedTypes"]]:
         if not str(event_type).startswith(self.type_enum.__name__):
             event_type = self.type_enum(event_type)
 
